@@ -2,14 +2,13 @@ use 5.006;
 
 package MoneyWorks;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10'; # Update MoneyWorks.pod, too.
 
 use #
 strict; use #
 warnings; no #
 warnings qw 'utf8 parenthesis regexp once qw';
 use warnings'register;
-BEGIN{ $] >= 5.012 and require Classic'Perl, import Classic'Perl }
 
 use Carp 'croak';
 use Exporter 5.57 'import';
@@ -170,7 +169,7 @@ sub _open {
     or croak "MoneyWorks could not be run: no path specified";
 
  # remove unsafe env vars temporarily
- local(@ENV{@bad_env_vars}), delete @ENV{@bad_env_vars} if ${AINT};
+ local(@ENV{@bad_env_vars}), delete @ENV{@bad_env_vars} if ${^TAINT};
 
  my $rego = $self->[_rego];
  open3(@_, $self->[_bina], '-h', $rego ? ('-r', $rego) : ())
@@ -338,8 +337,7 @@ This may be added later. There are currently serious problems with it.
 
  my %ret;
  for(split /;\s*/, $ret) {
-  no warnings;
-  split /:\s*/;
+  @_ = split /:\s*/;
   $ret{$_[0]} = $_[1];
  }
  \%ret;
